<?php

/**
 * @file
 * Theme functions for rendering fancy dates.
 */

function template_preprocess_fancy_dates(&$variables) {
  $date = $variables['date'];
  $options = is_array($variables['options']) ? $variables['options'] : array();

  if (is_string($date)) {
    // Its either an int timestamp from views (node created), or its a timestring
    // that can only be converted with strtotime.
    // Condition is executed regardless the result, so we don't have to create an else branch.
    if (!($timestamp = strtotime($date))) {
      $timestamp = intval($date);
    }
  }
  else {
    $timestamp = $date;
  }
  $variables = array_merge($variables, fancy_date($timestamp, $options));
}

function theme_fancy_dates_formatter_fancy_date($element) {
  $node = $element['#node'];
  $field_name = $element['#field_name'];
  $context = !empty($node->content) && !empty($node->content[$field_name]) ? $node->content[$field_name]['#context'] : 'full';
  $type_name = $element['#type_name'];
  $fields = content_fields();
  $field = $fields[$field_name];
  $item = $element['#item'];
  // Get the formatter settings, either the default settings for this node
  // type or the View settings stored in $node->date_info.
  $options = date_formatter_get_settings($field_name, $type_name, $context);
  if (!empty($node->date_info) && !empty($node->date_info->formatter_settings)) {
    $options = $node->date_info->formatter_settings;
  }
  switch ($options['fromto']['fromto']) {
    case 'value':
      $date1 = $element['#item']['value'];
      $date2 = $date1;
      break;    
    case 'value2':
      $date2 = $element['#item']['value2'];
      $date1 = $date2;
      break;
    default:
      $date1 = $element['#item']['value'];
      $date2 = $element['#item']['value2'];
      break;
  }

  $options = array();
  if ($date1 != $date2) {
    return theme('fancy_dates', $date1, $options) .
      theme('fancy_dates', $date2, $options);
  }
  else {
    $options['allowed'] = array('year', 'month', 'day');
    return theme('fancy_dates', $date1, $options);
  }
}

/**
 * Replace the function of theme_node_submitted in the node preprocess.
 */
function theme_fancy_date_submitted($node) {
  return t('Submitted by !username on !datetime',
    array(
      '!username' => theme('username', $node),
      '!datetime' => theme('fancy_dates', $node->created),
    ));
}
